Function compress_file

pub fn compress_file(
    source_path: &Path,
    target_path: &Path,
    quiet: bool,
) -> Result<()>
If quiet is false, lets messaging by the zstd tool show up on stdout/err. If true, silences reporting output but captures error messages and reports those in the resulting error.